@@ -1,10 +1,18 @@
+/* Gearman Perl front end
+ * Copyright (C) 2013 Data Differential, http://datadifferential.com/
+ * Copyright (C) 2009-2010 Dennis Schoen
+ * All rights reserved.
+ *
+ * This library is free software; you can redistribute it and/or modify
+ * it under the same terms as Perl itself, either Perl version 5.8.9 or,
+ * at your option, any later version of Perl 5 you may have available.
+ */
+
 #pragma once
 
 #include "EXTERN.h"
 #include "perl.h"
 #include "XSUB.h"
-#define NEED_newCONSTSUB
-#define NEED_sv_2pv_flags
 #include "ppport.h"
 
 #include <libgearman-1.0/gearman.h>
